==> vala-0.1.4.tar.bz2: vala-0.1.4/vala/valaparenthesizedexpression.h <==
/* valaparenthesizedexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAPARENTHESIZEDEXPRESSION_H__
#define __VALA_VALAPARENTHESIZEDEXPRESSION_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valaexpression.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_PARENTHESIZED_EXPRESSION (vala_parenthesized_expression_get_type ())
#define VALA_PARENTHESIZED_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpression))
#define VALA_PARENTHESIZED_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpressionClass))
#define VALA_IS_PARENTHESIZED_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PARENTHESIZED_EXPRESSION))
#define VALA_IS_PARENTHESIZED_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PARENTHESIZED_EXPRESSION))
#define VALA_PARENTHESIZED_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpressionClass))

typedef struct _ValaParenthesizedExpressionPrivate ValaParenthesizedExpressionPrivate;

/**
 * Represents a parenthesized expression in the source code.
 */
struct _ValaParenthesizedExpression {
	ValaExpression parent;
	ValaParenthesizedExpressionPrivate * priv;
};
struct _ValaParenthesizedExpressionClass {
	ValaExpressionClass parent;
};

ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression* _inner, ValaSourceReference* source);
ValaExpression* vala_parenthesized_expression_get_inner (ValaParenthesizedExpression* self);
void vala_parenthesized_expression_set_inner (ValaParenthesizedExpression* self, ValaExpression* value);
GType vala_parenthesized_expression_get_type (void);

G_END_DECLS

#endif

==> vala-0.1.7.tar.bz2: vala-0.1.7/vala/valaparenthesizedexpression.h <==
/* valaparenthesizedexpression.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAPARENTHESIZEDEXPRESSION_H__
#define __VALA_VALAPARENTHESIZEDEXPRESSION_H__

#include <glib.h>
#include <glib-object.h>
#include <vala/valaexpression.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_PARENTHESIZED_EXPRESSION (vala_parenthesized_expression_get_type ())
#define VALA_PARENTHESIZED_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpression))
#define VALA_PARENTHESIZED_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpressionClass))
#define VALA_IS_PARENTHESIZED_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_PARENTHESIZED_EXPRESSION))
#define VALA_IS_PARENTHESIZED_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PARENTHESIZED_EXPRESSION))
#define VALA_PARENTHESIZED_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpressionClass))

typedef struct _ValaParenthesizedExpressionPrivate ValaParenthesizedExpressionPrivate;

/**
 * Represents a parenthesized expression in the source code.
 */
struct _ValaParenthesizedExpression {
	ValaExpression parent_instance;
	ValaParenthesizedExpressionPrivate * priv;
};
struct _ValaParenthesizedExpressionClass {
	ValaExpressionClass parent_class;
};

ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression* _inner, ValaSourceReference* source);
ValaExpression* vala_parenthesized_expression_get_inner (ValaParenthesizedExpression* self);
void vala_parenthesized_expression_set_inner (ValaParenthesizedExpression* self, ValaExpression* value);
GType vala_parenthesized_expression_get_type (void);

G_END_DECLS

#endif
